#
# PySNMP MIB module FIBRE-CHANNEL-FE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/FIBRE-CHANNEL-FE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:12:36 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsIntersection")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( IpAddress, TimeTicks, Integer32, ModuleIdentity, Unsigned32, Counter64, iso, Counter32, Gauge32, NotificationType, MibIdentifier, ObjectIdentity, mib_2, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "TimeTicks", "Integer32", "ModuleIdentity", "Unsigned32", "Counter64", "iso", "Counter32", "Gauge32", "NotificationType", "MibIdentifier", "ObjectIdentity", "mib-2", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn")
( TextualConvention, DisplayString, TruthValue, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "TruthValue", "TimeStamp")
fcFeMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 75)).setRevisions(("2000-05-18 00:00",))
if mibBuilder.loadTexts: fcFeMIB.setLastUpdated('200005180000Z')
if mibBuilder.loadTexts: fcFeMIB.setOrganization('IETF IPFC Working Group')
if mibBuilder.loadTexts: fcFeMIB.setContactInfo('Kha Sin Teow\n                  Brocade Communications Systems,\n                  1901 Guadalupe Parkway,\n                  San Jose, CA 95131\n                  U.S.A\n                  Tel: +1 408 487 8180\n                  Fax: +1 408 487 8190\n                  Email: khasin@Brocade.COM\n\n                 WG Mailing list:ipfc@standards.gadzoox.com\n                 To Subscribe: ipfc-request@standards.gadzoox.com\n                 In Body: subscribe')
if mibBuilder.loadTexts: fcFeMIB.setDescription('The MIB module for Fibre Channel Fabric Element.')
fcFeMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 75, 1))
fcFeConfig = MibIdentifier((1, 3, 6, 1, 2, 1, 75, 1, 1))
fcFeStatus = MibIdentifier((1, 3, 6, 1, 2, 1, 75, 1, 2))
fcFeError = MibIdentifier((1, 3, 6, 1, 2, 1, 75, 1, 3))
fcFeAccounting = MibIdentifier((1, 3, 6, 1, 2, 1, 75, 1, 4))
fcFeCapabilities = MibIdentifier((1, 3, 6, 1, 2, 1, 75, 1, 5))
class MilliSeconds(Unsigned32, TextualConvention):
    pass

class MicroSeconds(Unsigned32, TextualConvention):
    pass

class FcNameId(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(8,8)
    fixedLength = 8

class FcAddressId(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(3,3)
    fixedLength = 3

class FcRxDataFieldSize(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(128,2112)

class FcBbCredit(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,32767)

class FcphVersion(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,255)

class FcStackedConnMode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("none", 1), ("transparent", 2), ("lockedDown", 3),)

class FcCosCap(Bits, TextualConvention):
    namedValues = NamedValues(("classF", 0), ("class1", 1), ("class2", 2), ("class3", 3), ("class4", 4), ("class5", 5), ("class6", 6),)

class FcFeModuleCapacity(Unsigned32, TextualConvention):
    pass

class FcFeFxPortCapacity(Unsigned32, TextualConvention):
    pass

class FcFeModuleIndex(Unsigned32, TextualConvention):
    pass

class FcFeFxPortIndex(Unsigned32, TextualConvention):
    pass

class FcFeNxPortIndex(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,126)

class FcBbCreditModel(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("regular", 1), ("alternate", 2),)

fcFeFabricName = MibScalar((1, 3, 6, 1, 2, 1, 75, 1, 1, 1), FcNameId()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fcFeFabricName.setDescription('The Name_Identifier of the Fabric to which this Fabric\n          Element belongs.')
fcFeElementName = MibScalar((1, 3, 6, 1, 2, 1, 75, 1, 1, 2), FcNameId()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fcFeElementName.setDescription('The Name_Identifier of the Fabric Element.')
fcFeModuleCapacity = MibScalar((1, 3, 6, 1, 2, 1, 75, 1, 1, 3), FcFeModuleCapacity()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFeModuleCapacity.setDescription('The maximum number of modules in the Fabric Element,\n          regardless of their current state.')
fcFeModuleTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 1, 4), )
if mibBuilder.loadTexts: fcFeModuleTable.setDescription('A table that contains, one entry for each module in the\n          Fabric Element, information of the modules.')
fcFeModuleEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 1, 4, 1), ).setIndexNames((0, "FIBRE-CHANNEL-FE-MIB", "fcFeModuleIndex"))
if mibBuilder.loadTexts: fcFeModuleEntry.setDescription('An entry containing the configuration parameters of a\n          module.')
fcFeModuleIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 4, 1, 1), FcFeModuleIndex())
if mibBuilder.loadTexts: fcFeModuleIndex.setDescription('This object identifies the module within the Fabric Element\n          for which this entry contains information. This value is\n          never greater than fcFeModuleCapacity.')
fcFeModuleDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 4, 1, 2), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFeModuleDescr.setDescription('A textual description of the module. This value should\n          include the full name and version identification of the\n          module.')
fcFeModuleObjectID = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 4, 1, 3), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFeModuleObjectID.setDescription("The vendor's authoritative identification of the module.\n          This value may be allocated within the SMI enterprises\n          subtree (1.3.6.1.4.1) and provides a straight-forward and\n          unambiguous means for determining what kind of module is\n          being managed.\n\n          For example, this object could take the value\n          1.3.6.1.4.1.99649.3.9 if vendor 'Neufe Inc.' was assigned\n          the subtree 1.3.6.1.4.1.99649, and had assigned the\n          identifier 1.3.6.1.4.1.99649.3.9 to its 'FeFiFo-16\n          PlugInCard.'")
fcFeModuleOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 4, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("online", 1), ("offline", 2), ("testing", 3), ("faulty", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFeModuleOperStatus.setDescription('This object indicates the operational status of the module:\n          online(1)   the module is functioning properly;\n          offline(2)  the module is not available;\n          testing(3)  the module is under testing; and\n          faulty(4)   the module is defective in some way.')
fcFeModuleLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 4, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFeModuleLastChange.setDescription('This object contains the value of sysUpTime when the module\n          entered its current operational status. A value of zero\n          indicates that the operational status of the module has not\n          changed since the agent last restarted.')
fcFeModuleFxPortCapacity = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 4, 1, 6), FcFeFxPortCapacity()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFeModuleFxPortCapacity.setDescription('The number of FxPort that can be contained within the\n          module. Within each module, the ports are uniquely numbered\n          in the range from 1 to fcFeModuleFxPortCapacity inclusive.\n          However, the numbers are not required to be contiguous.')
fcFeModuleName = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 4, 1, 7), FcNameId()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fcFeModuleName.setDescription('The Name_Identifier of the module.')
fcFxPortTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 1, 5), )
if mibBuilder.loadTexts: fcFxPortTable.setDescription('A table that contains, one entry for each FxPort in the\n         Fabric Element, configuration and service parameters of the\n         FxPorts.')
fcFxPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1), ).setIndexNames((0, "FIBRE-CHANNEL-FE-MIB", "fcFeModuleIndex"), (0, "FIBRE-CHANNEL-FE-MIB", "fcFxPortIndex"))
if mibBuilder.loadTexts: fcFxPortEntry.setDescription('An entry containing the configuration and service parameters\n         of a FxPort.')
fcFxPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 1), FcFeFxPortIndex())
if mibBuilder.loadTexts: fcFxPortIndex.setDescription('This object identifies the FxPort within the module.  This\n          number ranges from 1 to the value of fcFeModulePortCapacity\n          for the associated module. The value remains constant for\n          the identified FxPort until the module is re-initialized.')
fcFxPortName = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 2), FcNameId()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortName.setDescription('The World_wide Name of this FxPort.  Each FxPort has a\n          unique Port World_wide Name within the Fabric.')
fcFxPortFcphVersionHigh = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 3), FcphVersion()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortFcphVersionHigh.setDescription('The highest or most recent version of FC-PH that the FxPort\n          is configured to support.')
fcFxPortFcphVersionLow = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 4), FcphVersion()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortFcphVersionLow.setDescription('The lowest or earliest version of FC-PH that the FxPort is\n          configured to support.')
fcFxPortBbCredit = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 5), FcBbCredit()).setUnits('buffers').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortBbCredit.setDescription('The total number of receive buffers available for holding\n          Class 1 connect-request, Class 2 or 3 frames from the\n          attached NxPort.  It is for buffer-to-buffer flow control\n          in the direction from the attached NxPort (if applicable)\n          to FxPort.')
fcFxPortRxBufSize = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 6), FcRxDataFieldSize()).setUnits('bytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortRxBufSize.setDescription('The largest Data_Field Size (in octets) for an FT_1 frame\n          that can be received by the FxPort.')
fcFxPortRatov = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 7), MilliSeconds()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortRatov.setDescription('The Resource_Allocation_Timeout Value configured for the\n          FxPort.  This is used as the timeout value for determining\n          when to reuse an NxPort resource such as a\n          Recovery_Qualifier.  It represents E_D_TOV (see next\n          object) plus twice the maximum time that a frame may be\n          delayed within the Fabric and still be delivered.')
fcFxPortEdtov = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 8), MilliSeconds()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortEdtov.setDescription('The E_D_TOV value configured for the FxPort. The\n          Error_Detect_Timeout Value is used as the timeout value for\n          detecting an error condition.')
fcFxPortCosSupported = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 9), FcCosCap()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCosSupported.setDescription('A value indicating the set of Classes of Service supported\n          by the FxPort.')
fcFxPortIntermixSupported = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 10), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortIntermixSupported.setDescription('A flag indicating whether or not the FxPort supports an\n          Intermixed Dedicated Connection.')
fcFxPortStackedConnMode = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 11), FcStackedConnMode()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortStackedConnMode.setDescription('A value indicating the mode of Stacked Connect supported by\n          the FxPort.')
fcFxPortClass2SeqDeliv = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 12), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortClass2SeqDeliv.setDescription('A flag indicating whether or not Class 2 Sequential\n          Delivery is supported by the FxPort.')
fcFxPortClass3SeqDeliv = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 13), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortClass3SeqDeliv.setDescription('A flag indicating whether or not Class 3 Sequential\n          Delivery is supported by the FxPort.')
fcFxPortHoldTime = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 1, 5, 1, 14), MicroSeconds()).setUnits('microseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortHoldTime.setDescription('The maximum time (in microseconds) that the FxPort shall\n          hold a frame before discarding the frame if it is unable to\n          deliver the frame. The value 0 means that the FxPort does\n          not support this parameter.')
fcFxPortStatusTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 2, 1), )
if mibBuilder.loadTexts: fcFxPortStatusTable.setDescription('A table that contains, one entry for each FxPort in the\n          Fabric Element, operational status and parameters of the\n          FxPorts.')
fcFxPortStatusEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 2, 1, 1), )
fcFxPortEntry.registerAugmentions(("FIBRE-CHANNEL-FE-MIB", "fcFxPortStatusEntry"))
fcFxPortStatusEntry.setIndexNames(*fcFxPortEntry.getIndexNames())
if mibBuilder.loadTexts: fcFxPortStatusEntry.setDescription('An entry containing operational status and parameters of a\n          FxPort.')
fcFxPortID = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 1, 1, 1), FcAddressId()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortID.setDescription('The address identifier by which this FxPort is identified\n          within the Fabric.  The FxPort may assign its address\n          identifier to its attached NxPort(s) during Fabric Login.')
fcFxPortBbCreditAvailable = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 1, 1, 2), Gauge32()).setUnits('buffers').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortBbCreditAvailable.setDescription('The number of buffers currently available for receiving\n\n          frames from the attached port in the buffer-to-buffer flow\n          control. The value should be less than or equal to\n          fcFxPortBbCredit.')
fcFxPortOperMode = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unknown", 1), ("fPort", 2), ("flPort", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortOperMode.setDescription('The current operational mode of the FxPort.')
fcFxPortAdminMode = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(2, 3,))).clone(namedValues=NamedValues(("fPort", 2), ("flPort", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fcFxPortAdminMode.setDescription('The desired operational mode of the FxPort.')
fcFxPortPhysTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 2, 2), )
if mibBuilder.loadTexts: fcFxPortPhysTable.setDescription('A table that contains, one entry for each FxPort in the\n          Fabric Element, physical level status and parameters of the\n          FxPorts.')
fcFxPortPhysEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 2, 2, 1), )
fcFxPortEntry.registerAugmentions(("FIBRE-CHANNEL-FE-MIB", "fcFxPortPhysEntry"))
fcFxPortPhysEntry.setIndexNames(*fcFxPortEntry.getIndexNames())
if mibBuilder.loadTexts: fcFxPortPhysEntry.setDescription('An entry containing physical level status and parameters of\n          a FxPort.')
fcFxPortPhysAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("online", 1), ("offline", 2), ("testing", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fcFxPortPhysAdminStatus.setDescription('The desired state of the FxPort.  A management station may\n          place the FxPort in a desired state by setting this object\n          accordingly.  The testing(3) state indicates that no\n          operational frames can be passed.  When a Fabric Element\n          initializes, all FxPorts start with fcFxPortPhysAdminStatus\n          in the offline(2) state.  As the result of either explicit\n          management action or per configuration information\n          accessible by the Fabric Element, fcFxPortPhysAdminStatus\n          is then changed to either the online(1) or testing(3)\n          states, or remains in the offline state.')
fcFxPortPhysOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 2, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("online", 1), ("offline", 2), ("testing", 3), ("linkFailure", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortPhysOperStatus.setDescription('The current operational status of the FxPort.  The\n          testing(3) indicates that no operational frames can be\n          passed.  If fcFxPortPhysAdminStatus is offline(2) then\n          fcFxPortPhysOperStatus should be offline(2). If\n          fcFxPortPhysAdminStatus is changed to online(1) then\n          fcFxPortPhysOperStatus should change to online(1) if the\n\n          FxPort is ready to accept Fabric Login request from the\n          attached NxPort; it should proceed and remain in the link-\n          failure(4) state if and only if there is a fault that\n          prevents it from going to the online(1) state.')
fcFxPortPhysLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 2, 1, 3), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortPhysLastChange.setDescription("The value of sysUpTime at the time the FxPort entered its\n          current operational status. A value of zero indicates that\n          the FxPort's operational status has not changed since the\n          agent last restarted.")
fcFxPortPhysRttov = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 2, 1, 4), MilliSeconds()).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: fcFxPortPhysRttov.setDescription('The Receiver_Transmitter_Timeout value of the FxPort. This\n          is used by the receiver logic to detect Loss of\n          Synchronization.')
fcFxLoginTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 2, 3), )
if mibBuilder.loadTexts: fcFxLoginTable.setDescription('A table that contains, one entry for each NxPort attached\n          to a particular FxPort in the Fabric Element, services\n          parameters established from the most recent Fabric Login,\n          explicit or implicit. Note that an FxPort may have one or\n          more NxPort attached to it.')
fcFxLoginEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1), ).setIndexNames((0, "FIBRE-CHANNEL-FE-MIB", "fcFeModuleIndex"), (0, "FIBRE-CHANNEL-FE-MIB", "fcFxPortIndex"), (0, "FIBRE-CHANNEL-FE-MIB", "fcFxPortNxLoginIndex"))
if mibBuilder.loadTexts: fcFxLoginEntry.setDescription('An entry containing service parameters established from a\n          successful Fabric Login.')
fcFxPortNxLoginIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 1), FcFeNxPortIndex())
if mibBuilder.loadTexts: fcFxPortNxLoginIndex.setDescription('The object identifies the associated NxPort in the\n          attachment for which the entry contains information.')
fcFxPortFcphVersionAgreed = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 2), FcphVersion()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortFcphVersionAgreed.setDescription('The version of FC-PH that the FxPort has agreed to support\n          from the Fabric Login')
fcFxPortNxPortBbCredit = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 3), FcBbCredit()).setUnits('buffers').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortNxPortBbCredit.setDescription('The total number of buffers available for holding Class 1\n          connect-request, Class 2 or Class 3 frames to be\n          transmitted to the attached NxPort.  It is for buffer-to-\n          buffer flow control in the direction from FxPort to NxPort.\n          The buffer-to-buffer flow control mechanism is indicated in\n          the respective fcFxPortBbCreditModel.')
fcFxPortNxPortRxDataFieldSize = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 4), FcRxDataFieldSize()).setUnits('bytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortNxPortRxDataFieldSize.setDescription('The Receive Data Field Size of the attached NxPort. This\n          object specifies the largest Data Field Size for an FT_1\n          frame that can be received by the NxPort.')
fcFxPortCosSuppAgreed = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 5), FcCosCap()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCosSuppAgreed.setDescription('A variable indicating that the attached NxPort has\n          requested the FxPort for the support of classes of services\n          and the FxPort has granted the request.')
fcFxPortIntermixSuppAgreed = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 6), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortIntermixSuppAgreed.setDescription('A variable indicating that the attached NxPort has\n          requested the FxPort for the support of Intermix and the\n          FxPort has granted the request. This flag is only valid if\n          Class 1 service is supported.')
fcFxPortStackedConnModeAgreed = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 7), FcStackedConnMode()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortStackedConnModeAgreed.setDescription('A variable indicating whether the FxPort has agreed to\n          support stacked connect from the Fabric Login. This is only\n          meaningful if Class 1 service has been agreed.')
fcFxPortClass2SeqDelivAgreed = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 8), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortClass2SeqDelivAgreed.setDescription('A variable indicating whether the FxPort has agreed to\n          support Class 2 sequential delivery from the Fabric Login.\n          This is only meaningful if Class 2 service has been\n          agreed.')
fcFxPortClass3SeqDelivAgreed = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 9), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortClass3SeqDelivAgreed.setDescription('A flag indicating whether the FxPort has agreed to support\n          Class 3 sequential delivery from the Fabric Login. This is\n          only meaningful if Class 3 service has been agreed.')
fcFxPortNxPortName = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 10), FcNameId()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortNxPortName.setDescription('The port name of the attached NxPort.')
fcFxPortConnectedNxPort = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 11), FcAddressId()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortConnectedNxPort.setDescription("The address identifier of the destination NxPort with which\n          this FxPort is currently engaged in a either a Class 1 or\n          loop connection. If this FxPort is not engaged in a\n          connection, then the value of this object is '000000'H.")
fcFxPortBbCreditModel = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 2, 3, 1, 12), FcBbCreditModel()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fcFxPortBbCreditModel.setDescription('This object identifies the BB_Credit model used by the\n          FxPort.')
fcFxPortErrorTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 3, 1), )
if mibBuilder.loadTexts: fcFxPortErrorTable.setDescription('A table that contains, one entry for each FxPort, counters\n          that record the numbers of errors detected.')
fcFxPortErrorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1), )
fcFxPortEntry.registerAugmentions(("FIBRE-CHANNEL-FE-MIB", "fcFxPortErrorEntry"))
fcFxPortErrorEntry.setIndexNames(*fcFxPortEntry.getIndexNames())
if mibBuilder.loadTexts: fcFxPortErrorEntry.setDescription('An entry containing error counters of a FxPort.')
fcFxPortLinkFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortLinkFailures.setDescription('The number of link failures detected by this FxPort.')
fcFxPortSyncLosses = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortSyncLosses.setDescription('The number of loss of synchronization detected by the\n          FxPort.')
fcFxPortSigLosses = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortSigLosses.setDescription('The number of loss of signal detected by the FxPort.')
fcFxPortPrimSeqProtoErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortPrimSeqProtoErrors.setDescription('The number of primitive sequence protocol errors detected\n          by the FxPort.')
fcFxPortInvalidTxWords = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortInvalidTxWords.setDescription('The number of invalid transmission word detected by the\n          FxPort.')
fcFxPortInvalidCrcs = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortInvalidCrcs.setDescription('The number of invalid CRC detected by this FxPort.')
fcFxPortDelimiterErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortDelimiterErrors.setDescription('The number of Delimiter Errors detected by this FxPort.')
fcFxPortAddressIdErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortAddressIdErrors.setDescription('The number of address identifier errors detected by this\n\n          FxPort.')
fcFxPortLinkResetIns = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortLinkResetIns.setDescription('The number of Link Reset Protocol received by this FxPort\n          from the attached NxPort.')
fcFxPortLinkResetOuts = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortLinkResetOuts.setDescription('The number of Link Reset Protocol issued by this FxPort to\n          the attached NxPort.')
fcFxPortOlsIns = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortOlsIns.setDescription('The number of Offline Sequence received by this FxPort.')
fcFxPortOlsOuts = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 3, 1, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortOlsOuts.setDescription('The number of Offline Sequence issued by this FxPort.')
fcFxPortC1AccountingTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 4, 1), )
if mibBuilder.loadTexts: fcFxPortC1AccountingTable.setDescription('A table that contains, one entry for each FxPort in the\n          Fabric Element, Class 1 accounting information recorded\n          since the management agent has re-initialized.')
fcFxPortC1AccountingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1), )
fcFxPortEntry.registerAugmentions(("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1AccountingEntry"))
fcFxPortC1AccountingEntry.setIndexNames(*fcFxPortEntry.getIndexNames())
if mibBuilder.loadTexts: fcFxPortC1AccountingEntry.setDescription('An entry containing Class 1 accounting information for each\n          FxPort.')
fcFxPortC1InFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1InFrames.setDescription('The number of Class 1 frames (other than Class 1 connect-\n          request) received by this FxPort from its attached NxPort.')
fcFxPortC1OutFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1OutFrames.setDescription('The number of Class 1 frames (other than Class 1 connect-\n          request) delivered through this FxPort to its attached\n          NxPort.')
fcFxPortC1InOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1InOctets.setDescription('The number of Class 1 frame octets, including the frame\n          delimiters,  received by this FxPort from its attached\n          NxPort.')
fcFxPortC1OutOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1OutOctets.setDescription('The number of Class 1 frame octets, including the frame\n          delimiters, delivered through this FxPort its attached\n          NxPort.')
fcFxPortC1Discards = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1Discards.setDescription('The number of Class 1 frames discarded by this FxPort.')
fcFxPortC1FbsyFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1FbsyFrames.setDescription('The number of F_BSY frames generated by this FxPort against\n          Class 1 connect-request.')
fcFxPortC1FrjtFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1FrjtFrames.setDescription('The number of F_RJT frames generated by this FxPort against\n          Class 1 connect-request.')
fcFxPortC1InConnections = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1InConnections.setDescription('The number of Class 1 connections successfully established\n          in which the attached NxPort is the source of the connect-\n          request.')
fcFxPortC1OutConnections = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1OutConnections.setDescription('The number of Class 1 connections successfully established\n          in which the attached NxPort is the destination of the\n          connect-request.')
fcFxPortC1ConnTime = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 1, 1, 10), MilliSeconds()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC1ConnTime.setDescription('The cumulative time that this FxPort has been engaged in\n          Class 1 connection.  The amount of time is counted from\n          after a connect-request has been accepted until the\n          connection is disengaged, either by an EOFdt or Link\n          Reset.')
fcFxPortC2AccountingTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 4, 2), )
if mibBuilder.loadTexts: fcFxPortC2AccountingTable.setDescription('A table that contains, one entry for each FxPort in the\n          Fabric Element, Class 2 accounting information recorded\n          since the management agent has re-initialized.')
fcFxPortC2AccountingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 4, 2, 1), )
fcFxPortEntry.registerAugmentions(("FIBRE-CHANNEL-FE-MIB", "fcFxPortC2AccountingEntry"))
fcFxPortC2AccountingEntry.setIndexNames(*fcFxPortEntry.getIndexNames())
if mibBuilder.loadTexts: fcFxPortC2AccountingEntry.setDescription('An entry containing Class 2 accounting information for each\n          FxPort.')
fcFxPortC2InFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 2, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC2InFrames.setDescription('The number of Class 2 frames received by this FxPort from\n          its attached NxPort.')
fcFxPortC2OutFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC2OutFrames.setDescription('The number of Class 2 frames delivered through this FxPort\n          to its attached NxPort.')
fcFxPortC2InOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC2InOctets.setDescription('The number of Class 2 frame octets, including the frame\n          delimiters, received by this FxPort from its attached\n          NxPort.')
fcFxPortC2OutOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC2OutOctets.setDescription('The number of Class 2 frame octets, including the frame\n          delimiters, delivered through this FxPort to its attached\n          NxPort.')
fcFxPortC2Discards = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC2Discards.setDescription('The number of Class 2 frames discarded by this FxPort.')
fcFxPortC2FbsyFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC2FbsyFrames.setDescription('The number of F_BSY frames generated by this FxPort against\n          Class 2 frames.')
fcFxPortC2FrjtFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC2FrjtFrames.setDescription('The number of F_RJT frames generated by this FxPort against\n          Class 2 frames.')
fcFxPortC3AccountingTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 4, 3), )
if mibBuilder.loadTexts: fcFxPortC3AccountingTable.setDescription('A table that contains, one entry for each FxPort in the\n          Fabric Element, Class 3 accounting information recorded\n          since the management agent has re-initialized.')
fcFxPortC3AccountingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 4, 3, 1), )
fcFxPortEntry.registerAugmentions(("FIBRE-CHANNEL-FE-MIB", "fcFxPortC3AccountingEntry"))
fcFxPortC3AccountingEntry.setIndexNames(*fcFxPortEntry.getIndexNames())
if mibBuilder.loadTexts: fcFxPortC3AccountingEntry.setDescription('An entry containing Class 3 accounting information for each\n          FxPort.')
fcFxPortC3InFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 3, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC3InFrames.setDescription('The number of Class 3 frames received by this FxPort from\n          its attached NxPort.')
fcFxPortC3OutFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 3, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC3OutFrames.setDescription('The number of Class 3 frames delivered through this FxPort\n          to its attached NxPort.')
fcFxPortC3InOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 3, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC3InOctets.setDescription('The number of Class 3 frame octets, including the frame\n          delimiters, received by this FxPort from its attached\n          NxPort.')
fcFxPortC3OutOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 3, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC3OutOctets.setDescription('The number of Class 3 frame octets, including the frame\n          delimiters, delivered through this FxPort to its attached\n          NxPort.')
fcFxPortC3Discards = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 4, 3, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortC3Discards.setDescription('The number of Class 3 frames discarded by this FxPort.')
fcFxPortCapTable = MibTable((1, 3, 6, 1, 2, 1, 75, 1, 5, 1), )
if mibBuilder.loadTexts: fcFxPortCapTable.setDescription('A table that contains, one entry for each FxPort, the\n          capabilities of the port within the Fabric Element.')
fcFxPortCapEntry = MibTableRow((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1), )
fcFxPortEntry.registerAugmentions(("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapEntry"))
fcFxPortCapEntry.setIndexNames(*fcFxPortEntry.getIndexNames())
if mibBuilder.loadTexts: fcFxPortCapEntry.setDescription('An entry containing the Cap of a FxPort.')
fcFxPortCapFcphVersionHigh = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 1), FcphVersion()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapFcphVersionHigh.setDescription('The highest or most recent version of FC-PH that the FxPort\n          is capable of supporting.')
fcFxPortCapFcphVersionLow = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 2), FcphVersion()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapFcphVersionLow.setDescription('The lowest or earliest version of FC-PH that the FxPort is\n          capable of supporting.')
fcFxPortCapBbCreditMax = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 3), FcBbCredit()).setUnits('buffers').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapBbCreditMax.setDescription('The maximum number of receive buffers available for holding\n          Class 1 connect-request, Class 2 or Class 3 frames from the\n          attached NxPort.')
fcFxPortCapBbCreditMin = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 4), FcBbCredit()).setUnits('buffers').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapBbCreditMin.setDescription('The minimum number of receive buffers available for holding\n          Class 1 connect-request, Class 2 or Class 3 frames from the\n          attached NxPort.')
fcFxPortCapRxDataFieldSizeMax = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 5), FcRxDataFieldSize()).setUnits('bytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapRxDataFieldSizeMax.setDescription('The maximum size in bytes of the Data Field in a frame that\n          the FxPort is capable of receiving from its attached\n          NxPort.')
fcFxPortCapRxDataFieldSizeMin = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 6), FcRxDataFieldSize()).setUnits('bytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapRxDataFieldSizeMin.setDescription('The minimum size in bytes of the Data Field in a frame that\n          the FxPort is capable of receiving from its attached\n          NxPort.')
fcFxPortCapCos = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 7), FcCosCap()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapCos.setDescription('A value indicating the set of Classes of Service that the\n          FxPort is capable of supporting.')
fcFxPortCapIntermix = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 8), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapIntermix.setDescription('A flag indicating whether or not the FxPort is capable of\n          supporting the intermixing of Class 2 and Class 3 frames\n          during a Class 1 connection. This flag is only valid if the\n          port is capable of supporting Class 1 service.')
fcFxPortCapStackedConnMode = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 9), FcStackedConnMode()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapStackedConnMode.setDescription('A value indicating the mode of Stacked Connect request that\n          the FxPort is capable of supporting.')
fcFxPortCapClass2SeqDeliv = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 10), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapClass2SeqDeliv.setDescription('A flag indicating whether or not the FxPort is capable of\n          supporting Class 2 Sequential Delivery.')
fcFxPortCapClass3SeqDeliv = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 11), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapClass3SeqDeliv.setDescription('A flag indicating whether or not the FxPort is capable of\n          supporting Class 3 Sequential Delivery.')
fcFxPortCapHoldTimeMax = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 12), MicroSeconds()).setUnits('microseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapHoldTimeMax.setDescription('The maximum holding time (in microseconds) that the FxPort\n          is capable of supporting.')
fcFxPortCapHoldTimeMin = MibTableColumn((1, 3, 6, 1, 2, 1, 75, 1, 5, 1, 1, 13), MicroSeconds()).setUnits('microseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: fcFxPortCapHoldTimeMin.setDescription('The minimum holding time (in microseconds) that the FxPort\n          is capable of supporting.')
fcFeMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 75, 2))
fcFeMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 75, 2, 1))
fcFeMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 75, 2, 2))
fcFeMIBMinimumCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 75, 2, 1, 1)).setObjects(*(("FIBRE-CHANNEL-FE-MIB", "fcFeConfigGroup"), ("FIBRE-CHANNEL-FE-MIB", "fcFeStatusGroup"), ("FIBRE-CHANNEL-FE-MIB", "fcFeErrorGroup"),))
if mibBuilder.loadTexts: fcFeMIBMinimumCompliance.setDescription('The minimum compliance statement for SNMP entities\n          which implement the FIBRE-CHANNEL-FE-MIB.')
fcFeMIBFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 75, 2, 1, 2)).setObjects(*(("FIBRE-CHANNEL-FE-MIB", "fcFeConfigGroup"), ("FIBRE-CHANNEL-FE-MIB", "fcFeStatusGroup"), ("FIBRE-CHANNEL-FE-MIB", "fcFeErrorGroup"), ("FIBRE-CHANNEL-FE-MIB", "fcFeCapabilitiesGroup"), ("FIBRE-CHANNEL-FE-MIB", "fcFeClass1AccountingGroup"), ("FIBRE-CHANNEL-FE-MIB", "fcFeClass2AccountingGroup"), ("FIBRE-CHANNEL-FE-MIB", "fcFeClass3AccountingGroup"),))
if mibBuilder.loadTexts: fcFeMIBFullCompliance.setDescription('The full compliance statement for SNMP entities\n          which implement the FIBRE-CHANNEL-FE-MIB.')
fcFeConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 75, 2, 2, 1)).setObjects(*(("FIBRE-CHANNEL-FE-MIB", "fcFeFabricName"), ("FIBRE-CHANNEL-FE-MIB", "fcFeElementName"), ("FIBRE-CHANNEL-FE-MIB", "fcFeModuleCapacity"), ("FIBRE-CHANNEL-FE-MIB", "fcFeModuleDescr"), ("FIBRE-CHANNEL-FE-MIB", "fcFeModuleObjectID"), ("FIBRE-CHANNEL-FE-MIB", "fcFeModuleOperStatus"), ("FIBRE-CHANNEL-FE-MIB", "fcFeModuleLastChange"), ("FIBRE-CHANNEL-FE-MIB", "fcFeModuleFxPortCapacity"), ("FIBRE-CHANNEL-FE-MIB", "fcFeModuleName"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortName"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortFcphVersionHigh"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortFcphVersionLow"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortBbCredit"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortRxBufSize"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortRatov"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortEdtov"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCosSupported"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortIntermixSupported"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortStackedConnMode"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortClass2SeqDeliv"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortClass3SeqDeliv"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortHoldTime"),))
if mibBuilder.loadTexts: fcFeConfigGroup.setDescription('A collection of objects providing the configuration and service\n          parameters of the Fabric Element, the modules, and FxPorts.')
fcFeStatusGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 75, 2, 2, 2)).setObjects(*(("FIBRE-CHANNEL-FE-MIB", "fcFxPortID"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortBbCreditAvailable"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortOperMode"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortAdminMode"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortPhysAdminStatus"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortPhysOperStatus"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortPhysLastChange"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortPhysRttov"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortFcphVersionAgreed"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortNxPortBbCredit"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortNxPortRxDataFieldSize"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCosSuppAgreed"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortIntermixSuppAgreed"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortStackedConnModeAgreed"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortClass2SeqDelivAgreed"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortClass3SeqDelivAgreed"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortNxPortName"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortConnectedNxPort"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortBbCreditModel"),))
if mibBuilder.loadTexts: fcFeStatusGroup.setDescription('A collection of objects providing the operational status and\n         established service parameters for the Fabric Element and the\n         attached NxPorts.')
fcFeErrorGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 75, 2, 2, 3)).setObjects(*(("FIBRE-CHANNEL-FE-MIB", "fcFxPortLinkFailures"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortSyncLosses"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortSigLosses"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortPrimSeqProtoErrors"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortInvalidTxWords"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortInvalidCrcs"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortDelimiterErrors"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortAddressIdErrors"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortLinkResetIns"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortLinkResetOuts"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortOlsIns"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortOlsOuts"),))
if mibBuilder.loadTexts: fcFeErrorGroup.setDescription('A collection of objects providing various error\n          statistics detected by the FxPorts.')
fcFeClass1AccountingGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 75, 2, 2, 4)).setObjects(*(("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1InFrames"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1OutFrames"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1InOctets"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1OutOctets"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1Discards"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1FbsyFrames"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1FrjtFrames"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1InConnections"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1OutConnections"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC1ConnTime"),))
if mibBuilder.loadTexts: fcFeClass1AccountingGroup.setDescription('A collection of objects providing various class 1\n  performance statistics detected by the FxPorts.')
fcFeClass2AccountingGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 75, 2, 2, 5)).setObjects(*(("FIBRE-CHANNEL-FE-MIB", "fcFxPortC2InFrames"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC2OutFrames"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC2InOctets"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC2OutOctets"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC2Discards"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC2FbsyFrames"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC2FrjtFrames"),))
if mibBuilder.loadTexts: fcFeClass2AccountingGroup.setDescription('A collection of objects providing various class 2\n  performance statistics detected by the FxPorts.')
fcFeClass3AccountingGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 75, 2, 2, 6)).setObjects(*(("FIBRE-CHANNEL-FE-MIB", "fcFxPortC3InFrames"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC3OutFrames"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC3InOctets"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC3OutOctets"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortC3Discards"),))
if mibBuilder.loadTexts: fcFeClass3AccountingGroup.setDescription('A collection of objects providing various class 3\n          performance statistics detected by the FxPorts.')
fcFeCapabilitiesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 75, 2, 2, 7)).setObjects(*(("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapFcphVersionHigh"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapFcphVersionLow"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapBbCreditMax"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapBbCreditMin"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapRxDataFieldSizeMax"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapRxDataFieldSizeMin"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapCos"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapIntermix"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapStackedConnMode"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapClass2SeqDeliv"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapClass3SeqDeliv"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapHoldTimeMax"), ("FIBRE-CHANNEL-FE-MIB", "fcFxPortCapHoldTimeMin"),))
if mibBuilder.loadTexts: fcFeCapabilitiesGroup.setDescription('A collection of objects providing the inherent\n         capability of each FxPort within the Fabric Element.')
mibBuilder.exportSymbols("FIBRE-CHANNEL-FE-MIB", fcFxPortStackedConnModeAgreed=fcFxPortStackedConnModeAgreed, fcFxPortC1AccountingEntry=fcFxPortC1AccountingEntry, FcphVersion=FcphVersion, fcFxPortLinkResetIns=fcFxPortLinkResetIns, fcFeMIB=fcFeMIB, fcFeConfigGroup=fcFeConfigGroup, fcFxPortAddressIdErrors=fcFxPortAddressIdErrors, fcFxPortC2FrjtFrames=fcFxPortC2FrjtFrames, fcFxPortName=fcFxPortName, fcFxPortSigLosses=fcFxPortSigLosses, fcFeAccounting=fcFeAccounting, fcFeModuleName=fcFeModuleName, fcFxPortTable=fcFxPortTable, fcFxPortID=fcFxPortID, fcFxPortCosSuppAgreed=fcFxPortCosSuppAgreed, fcFeModuleObjectID=fcFeModuleObjectID, fcFxPortC1OutConnections=fcFxPortC1OutConnections, fcFxPortC2OutOctets=fcFxPortC2OutOctets, fcFxPortCapTable=fcFxPortCapTable, FcFeModuleCapacity=FcFeModuleCapacity, fcFxPortC2AccountingTable=fcFxPortC2AccountingTable, fcFxPortC2AccountingEntry=fcFxPortC2AccountingEntry, fcFxPortClass2SeqDeliv=fcFxPortClass2SeqDeliv, fcFxPortSyncLosses=fcFxPortSyncLosses, fcFeConfig=fcFeConfig, fcFxPortPhysTable=fcFxPortPhysTable, fcFxPortC1FrjtFrames=fcFxPortC1FrjtFrames, fcFxPortCapRxDataFieldSizeMax=fcFxPortCapRxDataFieldSizeMax, fcFxPortPhysLastChange=fcFxPortPhysLastChange, fcFeMIBMinimumCompliance=fcFeMIBMinimumCompliance, fcFxPortBbCredit=fcFxPortBbCredit, fcFxLoginTable=fcFxLoginTable, fcFeClass2AccountingGroup=fcFeClass2AccountingGroup, MilliSeconds=MilliSeconds, fcFeElementName=fcFeElementName, fcFxPortBbCreditAvailable=fcFxPortBbCreditAvailable, fcFxPortFcphVersionHigh=fcFxPortFcphVersionHigh, fcFxPortErrorTable=fcFxPortErrorTable, fcFxPortAdminMode=fcFxPortAdminMode, fcFxPortC1Discards=fcFxPortC1Discards, fcFxPortC2InFrames=fcFxPortC2InFrames, fcFxPortPhysRttov=fcFxPortPhysRttov, fcFxPortFcphVersionLow=fcFxPortFcphVersionLow, fcFxPortC1OutFrames=fcFxPortC1OutFrames, fcFxPortC3OutOctets=fcFxPortC3OutOctets, fcFxPortC3Discards=fcFxPortC3Discards, fcFeModuleLastChange=fcFeModuleLastChange, fcFxPortHoldTime=fcFxPortHoldTime, fcFxPortBbCreditModel=fcFxPortBbCreditModel, fcFxPortCapBbCreditMax=fcFxPortCapBbCreditMax, fcFxPortConnectedNxPort=fcFxPortConnectedNxPort, FcStackedConnMode=FcStackedConnMode, fcFxPortInvalidTxWords=fcFxPortInvalidTxWords, fcFxPortNxPortBbCredit=fcFxPortNxPortBbCredit, MicroSeconds=MicroSeconds, fcFxPortCapHoldTimeMax=fcFxPortCapHoldTimeMax, PYSNMP_MODULE_ID=fcFeMIB, FcBbCreditModel=FcBbCreditModel, fcFxPortPrimSeqProtoErrors=fcFxPortPrimSeqProtoErrors, fcFeMIBFullCompliance=fcFeMIBFullCompliance, fcFeModuleCapacity=fcFeModuleCapacity, fcFxPortC1AccountingTable=fcFxPortC1AccountingTable, fcFxPortNxPortRxDataFieldSize=fcFxPortNxPortRxDataFieldSize, fcFxPortC1OutOctets=fcFxPortC1OutOctets, fcFeClass3AccountingGroup=fcFeClass3AccountingGroup, fcFeErrorGroup=fcFeErrorGroup, fcFxPortNxLoginIndex=fcFxPortNxLoginIndex, fcFxPortNxPortName=fcFxPortNxPortName, fcFxPortCapBbCreditMin=fcFxPortCapBbCreditMin, fcFxPortInvalidCrcs=fcFxPortInvalidCrcs, fcFxPortOlsOuts=fcFxPortOlsOuts, fcFxPortCapClass3SeqDeliv=fcFxPortCapClass3SeqDeliv, fcFeModuleEntry=fcFeModuleEntry, fcFxPortOperMode=fcFxPortOperMode, fcFxPortC3AccountingTable=fcFxPortC3AccountingTable, FcCosCap=FcCosCap, fcFxPortCapClass2SeqDeliv=fcFxPortCapClass2SeqDeliv, FcAddressId=FcAddressId, fcFeModuleTable=fcFeModuleTable, fcFxPortPhysAdminStatus=fcFxPortPhysAdminStatus, fcFxPortIntermixSupported=fcFxPortIntermixSupported, fcFeModuleIndex=fcFeModuleIndex, fcFxLoginEntry=fcFxLoginEntry, fcFxPortPhysEntry=fcFxPortPhysEntry, fcFxPortCapFcphVersionHigh=fcFxPortCapFcphVersionHigh, fcFxPortCapStackedConnMode=fcFxPortCapStackedConnMode, fcFxPortLinkFailures=fcFxPortLinkFailures, fcFxPortCapEntry=fcFxPortCapEntry, fcFxPortC1FbsyFrames=fcFxPortC1FbsyFrames, fcFxPortC1InFrames=fcFxPortC1InFrames, fcFxPortCapCos=fcFxPortCapCos, FcFeModuleIndex=FcFeModuleIndex, fcFxPortFcphVersionAgreed=fcFxPortFcphVersionAgreed, fcFxPortEntry=fcFxPortEntry, fcFxPortC1InConnections=fcFxPortC1InConnections, FcFeFxPortCapacity=FcFeFxPortCapacity, fcFeCapabilitiesGroup=fcFeCapabilitiesGroup, FcNameId=FcNameId, fcFxPortIntermixSuppAgreed=fcFxPortIntermixSuppAgreed, fcFxPortCosSupported=fcFxPortCosSupported, fcFeClass1AccountingGroup=fcFeClass1AccountingGroup, fcFxPortLinkResetOuts=fcFxPortLinkResetOuts, fcFxPortCapHoldTimeMin=fcFxPortCapHoldTimeMin, FcBbCredit=FcBbCredit, fcFeModuleDescr=fcFeModuleDescr, fcFxPortC2OutFrames=fcFxPortC2OutFrames, fcFeStatus=fcFeStatus, FcRxDataFieldSize=FcRxDataFieldSize, fcFxPortCapIntermix=fcFxPortCapIntermix, fcFeModuleOperStatus=fcFeModuleOperStatus, FcFeNxPortIndex=FcFeNxPortIndex, fcFxPortIndex=fcFxPortIndex, fcFxPortC1ConnTime=fcFxPortC1ConnTime, fcFeCapabilities=fcFeCapabilities, fcFxPortC3InOctets=fcFxPortC3InOctets, fcFxPortC2Discards=fcFxPortC2Discards, fcFxPortStatusTable=fcFxPortStatusTable, fcFxPortC2InOctets=fcFxPortC2InOctets, fcFxPortClass2SeqDelivAgreed=fcFxPortClass2SeqDelivAgreed, fcFxPortClass3SeqDeliv=fcFxPortClass3SeqDeliv, fcFeMIBCompliances=fcFeMIBCompliances, fcFxPortCapFcphVersionLow=fcFxPortCapFcphVersionLow, fcFxPortC3InFrames=fcFxPortC3InFrames, fcFxPortStatusEntry=fcFxPortStatusEntry, fcFxPortClass3SeqDelivAgreed=fcFxPortClass3SeqDelivAgreed, fcFxPortC2FbsyFrames=fcFxPortC2FbsyFrames, fcFeMIBGroups=fcFeMIBGroups, fcFeStatusGroup=fcFeStatusGroup, fcFxPortStackedConnMode=fcFxPortStackedConnMode, fcFxPortC3OutFrames=fcFxPortC3OutFrames, fcFxPortEdtov=fcFxPortEdtov, fcFeMIBConformance=fcFeMIBConformance, fcFeError=fcFeError, fcFeModuleFxPortCapacity=fcFeModuleFxPortCapacity, FcFeFxPortIndex=FcFeFxPortIndex, fcFxPortPhysOperStatus=fcFxPortPhysOperStatus, fcFxPortOlsIns=fcFxPortOlsIns, fcFxPortC1InOctets=fcFxPortC1InOctets, fcFeMIBObjects=fcFeMIBObjects, fcFeFabricName=fcFeFabricName, fcFxPortErrorEntry=fcFxPortErrorEntry, fcFxPortCapRxDataFieldSizeMin=fcFxPortCapRxDataFieldSizeMin, fcFxPortRatov=fcFxPortRatov, fcFxPortDelimiterErrors=fcFxPortDelimiterErrors, fcFxPortC3AccountingEntry=fcFxPortC3AccountingEntry, fcFxPortRxBufSize=fcFxPortRxBufSize)



#
# PySNMP MIB module MSDP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MSDP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:22:15 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( Bits, Counter32, Unsigned32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, iso, ModuleIdentity, ObjectIdentity, experimental, IpAddress, MibIdentifier, Integer32, TimeTicks, Gauge32, Counter64, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "Counter32", "Unsigned32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "iso", "ModuleIdentity", "ObjectIdentity", "experimental", "IpAddress", "MibIdentifier", "Integer32", "TimeTicks", "Gauge32", "Counter64")
( DisplayString, TimeStamp, TruthValue, RowStatus, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TimeStamp", "TruthValue", "RowStatus", "TextualConvention")
msdpMIB = ModuleIdentity((1, 3, 6, 1, 3, 92)).setRevisions(("2006-08-01 00:00",))
if mibBuilder.loadTexts: msdpMIB.setLastUpdated('200608010000Z')
if mibBuilder.loadTexts: msdpMIB.setOrganization('IETF MBONED Working Group')
if mibBuilder.loadTexts: msdpMIB.setContactInfo('Bill Fenner\n            75 Willow Road\n            Menlo Park, CA  94025\n            Phone: +1 650 867 6073\n            E-mail: fenner@research.att.com\n\n            Dave Thaler\n            One Microsoft Way\n            Redmond, WA  98052\n            Phone: +1 425 703 8835\n            Email: dthaler@microsoft.com\n\n            MBONED Working Group: mboned@lists.uoregon.edu')
if mibBuilder.loadTexts: msdpMIB.setDescription('An experimental MIB module for MSDP Management and\n            Monitoring.\n            Copyright (C) The Internet Society 2006.  This version of\n            this MIB module is part of RFC 4624; see the RFC itself\n            for full legal notices.')
msdpMIBobjects = MibIdentifier((1, 3, 6, 1, 3, 92, 1))
msdp = MibIdentifier((1, 3, 6, 1, 3, 92, 1, 1))
msdpEnabled = MibScalar((1, 3, 6, 1, 3, 92, 1, 1, 1), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: msdpEnabled.setDescription('The state of MSDP on this MSDP speaker - globally enabled\n            or disabled.\n\n            Changes to this object should be stored to non-volatile\n            memory.')
msdpCacheLifetime = MibScalar((1, 3, 6, 1, 3, 92, 1, 1, 2), TimeTicks()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: msdpCacheLifetime.setDescription('The lifetime given to SA cache entries when created or\n            refreshed.  This is the [SG-State-Period] in the MSDP\n            spec.  A value of 0 means no SA caching is done by this\n            MSDP speaker.\n\n            Changes to this object should be stored to non-volatile\n            memory.\n\n            This object does not measure time per se; instead, it\n            is the delta from the time at which an SA message is\n            received at which it should be expired if not refreshed.\n            (i.e., it is the value of msdpSACacheExpiryTime\n            immediately after receiving an SA message applying to\n            that row.)  As such, TimeInterval would be a more\n            appropriate SYNTAX; it remains TimeTicks for backwards\n            compatibility.')
msdpNumSACacheEntries = MibScalar((1, 3, 6, 1, 3, 92, 1, 1, 3), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpNumSACacheEntries.setDescription('The total number of entries in the SA Cache table.')
msdpRPAddress = MibScalar((1, 3, 6, 1, 3, 92, 1, 1, 11), IpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: msdpRPAddress.setDescription('The Rendezvous Point (RP) address used when sourcing\n            MSDP SA messages.  May be 0.0.0.0 on non-RPs.\n\n            Changes to this object should be stored to non-volatile\n            memory.')
msdpRequestsTable = MibTable((1, 3, 6, 1, 3, 92, 1, 1, 4), )
if mibBuilder.loadTexts: msdpRequestsTable.setDescription("The (conceptual) table listing group ranges and MSDP peers\n            used when deciding where to send an SA Request message, when\n            required.  If SA Requests are not enabled, this table may be\n            empty.\n\n            In order to choose a peer to whom to send an SA Request for\n            a given group, G, the subset of entries in this table whose\n            (msdpRequestsPeerType, msdpRequestsPeer) tuple represents a\n            peer whose msdpPeerState is established are examined.  The\n            set is further reduced by examining only those entries for\n            which msdpPeerRequestsGroupAddressType equals the address\n            type of G.  The entries with the highest value of\n            msdpRequestsGroupPrefix are considered, where the group G\n            falls within the range described by the combination of\n            msdpRequestsGroup and msdpRequestsGroupPrefix.  (This\n            sequence is commonly known as a 'longest-match' lookup.)\n\n            Finally, if multiple entries remain, the entry with the\n            lowest value of msdpRequestsPriority is chosen.  The SA\n            Request message is sent to the peer described by this row.")
msdpRequestsEntry = MibTableRow((1, 3, 6, 1, 3, 92, 1, 1, 4, 1), ).setIndexNames((0, "MSDP-MIB", "msdpRequestsGroupAddress"), (0, "MSDP-MIB", "msdpRequestsGroupMask"))
if mibBuilder.loadTexts: msdpRequestsEntry.setDescription('An entry (conceptual row) representing a group range\n            used when deciding where to send an SA Request\n            message.')
msdpRequestsGroupAddress = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 4, 1, 1), IpAddress())
if mibBuilder.loadTexts: msdpRequestsGroupAddress.setDescription('The group address that, when combined with the mask\n            in this entry, represents the group range to which\n            this row applies.')
msdpRequestsGroupMask = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 4, 1, 2), IpAddress())
if mibBuilder.loadTexts: msdpRequestsGroupMask.setDescription('The mask that, when combined with the group address\n            in this entry, represents the group range to which\n            this row applies.')
msdpRequestsPeer = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 4, 1, 3), IpAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpRequestsPeer.setDescription("The peer to which MSDP SA Requests for groups matching\n            this entry's group range will be sent.  This object,\n            combined with msdpRequestsPeerType, must match the INDEX\n            of a row in the msdpPeerTable, and to be considered,\n            this peer's msdpPeerState must be established.")
msdpRequestsStatus = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 4, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpRequestsStatus.setDescription('The status of this row, by which new rows may be added\n            to the table or old rows may be deleted.')
msdpPeerTable = MibTable((1, 3, 6, 1, 3, 92, 1, 1, 5), )
if mibBuilder.loadTexts: msdpPeerTable.setDescription("The (conceptual) table listing the MSDP speaker's peers.")
msdpPeerEntry = MibTableRow((1, 3, 6, 1, 3, 92, 1, 1, 5, 1), ).setIndexNames((0, "MSDP-MIB", "msdpPeerRemoteAddress"))
if mibBuilder.loadTexts: msdpPeerEntry.setDescription("An entry (conceptual row) representing an MSDP peer.\n\n            If row creation is supported, dynamically added rows are\n            added to the system's stable configuration (corresponding\n            to a StorageType value of nonVolatile).  ")
msdpPeerRemoteAddress = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 1), IpAddress())
if mibBuilder.loadTexts: msdpPeerRemoteAddress.setDescription('The address of the remote MSDP peer.')
msdpPeerState = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("inactive", 1), ("listen", 2), ("connecting", 3), ("established", 4), ("disabled", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerState.setDescription('The state of the MSDP TCP connection with this peer.')
msdpPeerRPFFailures = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerRPFFailures.setDescription('The number of SA messages received from this peer that\n            failed the Peer-RPF check.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerInSAs = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerInSAs.setDescription('The number of MSDP SA messages received on this\n            connection.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerOutSAs = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerOutSAs.setDescription('The number of MSDP SA messages transmitted on this\n            connection.\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerInSARequests = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerInSARequests.setDescription('The number of MSDP SA-Request messages received on this\n            connection.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerOutSARequests = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerOutSARequests.setDescription('The number of MSDP SA-Request messages transmitted on\n            this connection.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerInSAResponses = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerInSAResponses.setDescription('The number of MSDP SA-Response messages received on this\n            connection.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerOutSAResponses = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerOutSAResponses.setDescription('The number of MSDP SA Response messages transmitted on\n            this TCP connection.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerInControlMessages = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerInControlMessages.setDescription('The total number of MSDP messages, excluding encapsulated\n            data packets, received on this TCP connection.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerOutControlMessages = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerOutControlMessages.setDescription('The total number of MSDP messages, excluding encapsulated\n            data packets, transmitted on this TCP connection.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerInDataPackets = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerInDataPackets.setDescription('The total number of encapsulated data packets received\n            from this peer.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerOutDataPackets = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerOutDataPackets.setDescription('The total number of encapsulated data packets sent to\n            this peer.\n\n            Discontinuities in the value of this counter can occur at\n            re-initialization of the management system, and at other\n            times as indicated by the value of\n            msdpPeerDiscontinuityTime.')
msdpPeerFsmEstablishedTransitions = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerFsmEstablishedTransitions.setDescription('The total number of times the MSDP FSM transitioned into\n            the ESTABLISHED state.')
msdpPeerFsmEstablishedTime = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 16), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerFsmEstablishedTime.setDescription('This timestamp is set to the value of sysUpTime when a\n            peer transitions into or out of the ESTABLISHED state.\n            It is set to zero when the MSDP speaker is booted.')
msdpPeerInMessageTime = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 17), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerInMessageTime.setDescription('The sysUpTime value when the last MSDP message was\n            received from the peer.  It is set to zero when the MSDP\n            speaker is booted.')
msdpPeerLocalAddress = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 18), IpAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpPeerLocalAddress.setDescription("The local IP address used for this entry's MSDP TCP\n            connection.")
msdpPeerConnectRetryInterval = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 20), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(30)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpPeerConnectRetryInterval.setDescription('Time interval, in seconds, for the [ConnectRetry-period]\n            for this peer.')
msdpPeerHoldTimeConfigured = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 21), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(3,65535),)).clone(75)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpPeerHoldTimeConfigured.setDescription('Time interval, in seconds, for the [HoldTime-Period]\n            configured for this MSDP speaker with this peer.  If the\n            value of this object is zero (0), the MSDP connection is\n            never torn down due to the absence of messages from the\n            peer.')
msdpPeerKeepAliveConfigured = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 22), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(1,21845),)).clone(60)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpPeerKeepAliveConfigured.setDescription('Time interval, in seconds, for the [KeepAlive-Period]\n            configured for this MSDP speaker with this peer.  If the\n            value of this object is zero (0), no periodic KEEPALIVE\n            messages are sent to the peer after the MSDP connection\n            has been established.')
msdpPeerDataTtl = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 23), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255)).clone(1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpPeerDataTtl.setDescription('The minimum TTL a packet is required to have before it\n            may be forwarded using SA encapsulation to this peer.')
msdpPeerProcessRequestsFrom = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 24), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpPeerProcessRequestsFrom.setDescription('This object indicates whether to process MSDP SA\n            Request messages from this peer.  If True(1), MSDP SA\n            Request messages from this peer are processed and replied\n            to (if appropriate) with SA Response messages.  If\n            False(2), MSDP SA Request messages from this peer are\n            silently ignored.  It defaults to False when\n            msdpCacheLifetime is 0 and to True when msdpCacheLifetime\n            is non-0.\n\n            This object is deprecated because MSDP SA Requests were\n            removed from the MSDP specification.')
msdpPeerStatus = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 25), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpPeerStatus.setDescription("The RowStatus object by which peers can be added and\n            deleted.  A transition to 'active' will cause the MSDP\n            'Enable MSDP peering with P' Event to be generated.  A\n            transition out of the 'active' state will cause the MSDP\n            'Disable MSDP peering with P' Event to be generated.\n            Care should be used in providing write access to this\n            object without adequate authentication.\n\n            msdpPeerRemoteAddress is the only variable that must be\n            set to a valid value before the row can be activated.\n            Since this is the table's INDEX, a row can be activated\n            by simply setting the msdpPeerStatus variable.\n\n            It is possible to modify other columns in the same\n            conceptual row when the status value is active(1).")
msdpPeerRemotePort = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 26), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(639)).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerRemotePort.setDescription('The remote port for the TCP connection between the MSDP\n            peers.')
msdpPeerLocalPort = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 27), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(639)).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerLocalPort.setDescription('The local port for the TCP connection between the MSDP\n            peers.')
msdpPeerEncapsulationType = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 29), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1,))).clone(namedValues=NamedValues(("none", 0), ("tcp", 1),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpPeerEncapsulationType.setDescription('The encapsulation in use when encapsulating data in SA\n            messages to this peer.')
msdpPeerConnectionAttempts = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 30), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerConnectionAttempts.setDescription('The number of times the state machine has transitioned\n            from INACTIVE to CONNECTING.')
msdpPeerInNotifications = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 31), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerInNotifications.setDescription('The number of MSDP Notification messages received from\n            this peer.\n            This object is deprecated because MSDP Notifications have\n            been removed from the spec.')
msdpPeerOutNotifications = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 32), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerOutNotifications.setDescription('The number of MSDP Notification messages transmitted to\n            this peer.\n\n            This object is deprecated because MSDP Notifications have\n            been removed from the spec.')
msdpPeerLastError = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 33), OctetString().subtype(subtypeSpec=ValueSizeConstraint(2,2)).setFixedLength(2).clone(hexValue="0000")).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerLastError.setDescription('The last error code and subcode received via Notification\n            from this peer.  If no error has occurred, this field is\n            zero.  Otherwise, the first byte of this two-byte OCTET\n            STRING contains the O-bit and error code, and the second\n            byte contains the subcode.\n            This object is deprecated because MSDP Notifications have\n            been removed from the spec.')
msdpPeerDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 5, 1, 34), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpPeerDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion at\n            which one or more of this entry's counters suffered a\n            discontinuity.  See the DESCRIPTION of each object to see\n            if it is expected to have discontinuities.  These\n            discontinuities may occur at peer connection\n            establishment.\n\n            If no such discontinuities have occurred since the last\n            reinitialization of the local management subsystem, then\n            this object contains a zero value.")
msdpSACacheTable = MibTable((1, 3, 6, 1, 3, 92, 1, 1, 6), )
if mibBuilder.loadTexts: msdpSACacheTable.setDescription("The (conceptual) table listing the MSDP SA advertisements\n            currently in the MSDP speaker's cache.")
msdpSACacheEntry = MibTableRow((1, 3, 6, 1, 3, 92, 1, 1, 6, 1), ).setIndexNames((0, "MSDP-MIB", "msdpSACacheGroupAddr"), (0, "MSDP-MIB", "msdpSACacheSourceAddr"), (0, "MSDP-MIB", "msdpSACacheOriginRP"))
if mibBuilder.loadTexts: msdpSACacheEntry.setDescription('An entry (conceptual row) representing an MSDP SA\n            advertisement.  The INDEX to this table includes\n            msdpSACacheOriginRP for diagnosing incorrect MSDP\n            advertisements; normally, a Group and Source pair would\n            be unique.\n\n            Row creation is not permitted; msdpSACacheStatus may only\n            be used to delete rows from this table.')
msdpSACacheGroupAddr = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 1), IpAddress())
if mibBuilder.loadTexts: msdpSACacheGroupAddr.setDescription('The group address of the SA Cache entry.')
msdpSACacheSourceAddr = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 2), IpAddress())
if mibBuilder.loadTexts: msdpSACacheSourceAddr.setDescription('The source address of the SA Cache entry.')
msdpSACacheOriginRP = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 3), IpAddress())
if mibBuilder.loadTexts: msdpSACacheOriginRP.setDescription("The RP of the SA Cache entry.  This field is in the INDEX\n            in order to catch multiple RP's advertising the same\n            source and group.")
msdpSACachePeerLearnedFrom = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 4), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpSACachePeerLearnedFrom.setDescription('The peer from which this SA Cache entry was last\n            accepted.  This address must correspond to the\n            msdpPeerRemoteAddress value for a row in the MSDP Peer\n            Table.  This should be 0.0.0.0 on the router that\n            originated the entry.')
msdpSACacheRPFPeer = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 5), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpSACacheRPFPeer.setDescription('The peer from which an SA message corresponding to this\n            cache entry would be accepted (i.e., the RPF peer for\n            msdpSACacheOriginRP).  This may be different than\n            msdpSACachePeerLearnedFrom if this entry was created by\n            an MSDP SA-Response.  This address must correspond to\n            the msdpPeerRemoteAddress value for a row in the MSDP\n            Peer Table, or it may be 0.0.0.0 if no RPF peer exists.')
msdpSACacheInSAs = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpSACacheInSAs.setDescription('The number of MSDP SA messages received relevant to this\n            cache entry.  This object must be initialized to zero\n            when creating a cache entry.')
msdpSACacheInDataPackets = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpSACacheInDataPackets.setDescription('The number of MSDP-encapsulated data packets received\n            relevant to this cache entry.  This object must be\n            initialized to zero when creating a cache entry.')
msdpSACacheUpTime = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 8), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpSACacheUpTime.setDescription('The time since this entry was first placed in the SA\n            cache.\n            The first epoch is the time that the entry was first\n            placed in the SA cache, and the second epoch is the\n            current time.')
msdpSACacheExpiryTime = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 9), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: msdpSACacheExpiryTime.setDescription('The time remaining before this entry will expire from\n            the SA cache.\n\n            The first epoch is now, and the second epoch is the time\n            that the entry will expire.')
msdpSACacheStatus = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 6, 1, 10), RowStatus().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 6,))).clone(namedValues=NamedValues(("active", 1), ("destroy", 6),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: msdpSACacheStatus.setDescription("The status of this row in the table.  The only allowable\n            actions are to retrieve the status, which will be\n            'active', or to set the status to 'destroy' in order to\n            remove this entry from the cache.\n\n            Row creation is not permitted.\n\n            No columnar objects are writable, so there are none that\n            may be changed while the status value is active(1).")
msdpMeshGroupTable = MibTable((1, 3, 6, 1, 3, 92, 1, 1, 12), )
if mibBuilder.loadTexts: msdpMeshGroupTable.setDescription('The (conceptual) table listing MSDP Mesh Group\n            configuration.')
msdpMeshGroupEntry = MibTableRow((1, 3, 6, 1, 3, 92, 1, 1, 12, 1), ).setIndexNames((0, "MSDP-MIB", "msdpMeshGroupName"), (0, "MSDP-MIB", "msdpMeshGroupPeerAddress"))
if mibBuilder.loadTexts: msdpMeshGroupEntry.setDescription("An entry (conceptual row) representing a peer in an MSDP\n            Mesh Group.\n\n            If row creation is supported, dynamically added rows are\n            added to the system's stable configuration\n            (corresponding to a StorageType value of nonVolatile).")
msdpMeshGroupName = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 12, 1, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(1,64)))
if mibBuilder.loadTexts: msdpMeshGroupName.setDescription('The name of the mesh group.')
msdpMeshGroupPeerAddress = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 12, 1, 2), IpAddress())
if mibBuilder.loadTexts: msdpMeshGroupPeerAddress.setDescription('A peer address that is a member of the mesh group with\n            name msdpMeshGroupName.  The msdpMeshGroupPeerAddress\n            must match a row in the msdpPeerTable.')
msdpMeshGroupStatus = MibTableColumn((1, 3, 6, 1, 3, 92, 1, 1, 12, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: msdpMeshGroupStatus.setDescription("This entry's status, by which new entries may be added\n               to the table and old entries deleted.\n\n               msdpMeshGroupName and msdpMeshGroupPeerAddress must be\n               set to valid values before the row can be activated.\n               Since these are the table's INDEX, a row can be activated\n               by simply setting the msdpMeshGroupStatus variable.\n\n               It is not possible to modify other columns in the same\n               conceptual row when the status value is active(1),\n               because the only other objects in the row are part of the\n               INDEX.  Changing one of these changes the row, so an old\n               row must be deleted and a new one created.")
msdpTraps = MibIdentifier((1, 3, 6, 1, 3, 92, 1, 1, 0))
msdpEstablished = NotificationType((1, 3, 6, 1, 3, 92, 1, 1, 0, 1)).setObjects(*(("MSDP-MIB", "msdpPeerFsmEstablishedTransitions"),))
if mibBuilder.loadTexts: msdpEstablished.setDescription('The MSDP Established event is generated when the MSDP FSM\n            enters the ESTABLISHED state.')
msdpBackwardTransition = NotificationType((1, 3, 6, 1, 3, 92, 1, 1, 0, 2)).setObjects(*(("MSDP-MIB", "msdpPeerState"),))
if mibBuilder.loadTexts: msdpBackwardTransition.setDescription('The MSDPBackwardTransition Event is generated when the\n            MSDP FSM moves from a higher-numbered state to a\n            lower-numbered state.')
msdpMIBConformance = MibIdentifier((1, 3, 6, 1, 3, 92, 1, 1, 8))
msdpMIBCompliances = MibIdentifier((1, 3, 6, 1, 3, 92, 1, 1, 8, 1))
msdpMIBGroups = MibIdentifier((1, 3, 6, 1, 3, 92, 1, 1, 8, 2))
msdpMIBCompliance = ModuleCompliance((1, 3, 6, 1, 3, 92, 1, 1, 8, 1, 1)).setObjects(*(("MSDP-MIB", "msdpMIBGlobalsGroup"), ("MSDP-MIB", "msdpMIBPeerGroup"), ("MSDP-MIB", "msdpMIBNotificationGroup"), ("MSDP-MIB", "msdpMIBEncapsulationGroup"), ("MSDP-MIB", "msdpMIBSACacheGroup"), ("MSDP-MIB", "msdpMIBRequestsGroup"), ("MSDP-MIB", "msdpMIBRPGroup"), ("MSDP-MIB", "msdpMIBMeshGroupGroup"),))
if mibBuilder.loadTexts: msdpMIBCompliance.setDescription('The compliance statement for entities that implement a pre-\n            RFC version of MSDP.  This statement is deprecated because\n            it includes objects used for managing/monitoring aspects of\n            MSDP that were removed before it was published as an RFC.')
msdpMIBFullCompliance = ModuleCompliance((1, 3, 6, 1, 3, 92, 1, 1, 8, 1, 2)).setObjects(*(("MSDP-MIB", "msdpMIBGlobalsGroup"), ("MSDP-MIB", "msdpMIBPeerGroup2"), ("MSDP-MIB", "msdpMIBSACacheGroup"), ("MSDP-MIB", "msdpMIBEncapsulationGroup"), ("MSDP-MIB", "msdpMIBRPGroup"), ("MSDP-MIB", "msdpMIBMeshGroupGroup"),))
if mibBuilder.loadTexts: msdpMIBFullCompliance.setDescription('The compliance statement for entities that implement MSDP\n            (RFC3618).')
msdpMIBReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 3, 92, 1, 1, 8, 1, 3)).setObjects(*(("MSDP-MIB", "msdpMIBGlobalsGroup"), ("MSDP-MIB", "msdpMIBPeerGroup2"), ("MSDP-MIB", "msdpMIBSACacheGroup"), ("MSDP-MIB", "msdpMIBEncapsulationGroup"), ("MSDP-MIB", "msdpMIBRPGroup"), ("MSDP-MIB", "msdpMIBMeshGroupGroup"),))
if mibBuilder.loadTexts: msdpMIBReadOnlyCompliance.setDescription('The compliance statement for entities that implement MSDP\n            (RFC3618), but do not permit configuration (or only permit\n            partial configuration) via SNMP.')
msdpMIBGlobalsGroup = ObjectGroup((1, 3, 6, 1, 3, 92, 1, 1, 8, 2, 1)).setObjects(*(("MSDP-MIB", "msdpEnabled"),))
if mibBuilder.loadTexts: msdpMIBGlobalsGroup.setDescription('A collection of objects providing information on global MSDP\n            state.')
msdpMIBPeerGroup = ObjectGroup((1, 3, 6, 1, 3, 92, 1, 1, 8, 2, 2)).setObjects(*(("MSDP-MIB", "msdpPeerRPFFailures"), ("MSDP-MIB", "msdpPeerState"), ("MSDP-MIB", "msdpPeerInSAs"), ("MSDP-MIB", "msdpPeerOutSAs"), ("MSDP-MIB", "msdpPeerInSARequests"), ("MSDP-MIB", "msdpPeerOutSARequests"), ("MSDP-MIB", "msdpPeerInSAResponses"), ("MSDP-MIB", "msdpPeerOutSAResponses"), ("MSDP-MIB", "msdpPeerInNotifications"), ("MSDP-MIB", "msdpPeerOutNotifications"), ("MSDP-MIB", "msdpPeerInControlMessages"), ("MSDP-MIB", "msdpPeerOutControlMessages"), ("MSDP-MIB", "msdpPeerFsmEstablishedTransitions"), ("MSDP-MIB", "msdpPeerFsmEstablishedTime"), ("MSDP-MIB", "msdpPeerLocalAddress"), ("MSDP-MIB", "msdpPeerRemotePort"), ("MSDP-MIB", "msdpPeerLocalPort"), ("MSDP-MIB", "msdpPeerConnectRetryInterval"), ("MSDP-MIB", "msdpPeerHoldTimeConfigured"), ("MSDP-MIB", "msdpPeerKeepAliveConfigured"), ("MSDP-MIB", "msdpPeerInMessageTime"), ("MSDP-MIB", "msdpPeerProcessRequestsFrom"), ("MSDP-MIB", "msdpPeerConnectionAttempts"), ("MSDP-MIB", "msdpPeerLastError"), ("MSDP-MIB", "msdpPeerStatus"), ("MSDP-MIB", "msdpPeerDiscontinuityTime"),))
if mibBuilder.loadTexts: msdpMIBPeerGroup.setDescription('A collection of objects for managing MSDP peers.  This group\n            is deprecated in favor of msdpMIBPeerGroup2 because it\n            contains objects for managing aspects of MSDP that were\n            removed before it was published as an RFC.')
msdpMIBEncapsulationGroup = ObjectGroup((1, 3, 6, 1, 3, 92, 1, 1, 8, 2, 3)).setObjects(*(("MSDP-MIB", "msdpPeerInDataPackets"), ("MSDP-MIB", "msdpPeerOutDataPackets"), ("MSDP-MIB", "msdpPeerDataTtl"), ("MSDP-MIB", "msdpPeerEncapsulationType"),))
if mibBuilder.loadTexts: msdpMIBEncapsulationGroup.setDescription('A collection of objects for managing encapsulations if the\n            MSDP encapsulation interfaces are not given interface\n            indices.')
msdpMIBSACacheGroup = ObjectGroup((1, 3, 6, 1, 3, 92, 1, 1, 8, 2, 4)).setObjects(*(("MSDP-MIB", "msdpCacheLifetime"), ("MSDP-MIB", "msdpNumSACacheEntries"), ("MSDP-MIB", "msdpSACachePeerLearnedFrom"), ("MSDP-MIB", "msdpSACacheRPFPeer"), ("MSDP-MIB", "msdpSACacheInSAs"), ("MSDP-MIB", "msdpSACacheInDataPackets"), ("MSDP-MIB", "msdpSACacheUpTime"), ("MSDP-MIB", "msdpSACacheExpiryTime"), ("MSDP-MIB", "msdpSACacheStatus"),))
if mibBuilder.loadTexts: msdpMIBSACacheGroup.setDescription('A collection of objects for managing MSDP SA cache entries.')
msdpMIBNotificationGroup = NotificationGroup((1, 3, 6, 1, 3, 92, 1, 1, 8, 2, 5)).setObjects(*(("MSDP-MIB", "msdpEstablished"), ("MSDP-MIB", "msdpBackwardTransition"),))
if mibBuilder.loadTexts: msdpMIBNotificationGroup.setDescription('A collection of notifications for signaling changes in MSDP\n            peer relationships.')
msdpMIBRequestsGroup = ObjectGroup((1, 3, 6, 1, 3, 92, 1, 1, 8, 2, 6)).setObjects(*(("MSDP-MIB", "msdpRequestsPeer"), ("MSDP-MIB", "msdpRequestsStatus"),))
if mibBuilder.loadTexts: msdpMIBRequestsGroup.setDescription('A collection of objects for managing MSDP Request\n            transmission.  This group is deprecated because Requests\n            were removed from MSDP before its publication as an RFC.')
msdpMIBRPGroup = ObjectGroup((1, 3, 6, 1, 3, 92, 1, 1, 8, 2, 7)).setObjects(*(("MSDP-MIB", "msdpRPAddress"),))
if mibBuilder.loadTexts: msdpMIBRPGroup.setDescription('A collection of objects for MSDP speakers that source MSDP\n            messages.')
msdpMIBMeshGroupGroup = ObjectGroup((1, 3, 6, 1, 3, 92, 1, 1, 8, 2, 8)).setObjects(*(("MSDP-MIB", "msdpMeshGroupStatus"),))
if mibBuilder.loadTexts: msdpMIBMeshGroupGroup.setDescription('A collection of objects for MSDP speakers that can\n            participate in MSDP mesh groups.')
msdpMIBPeerGroup2 = ObjectGroup((1, 3, 6, 1, 3, 92, 1, 1, 8, 2, 9)).setObjects(*(("MSDP-MIB", "msdpPeerRPFFailures"), ("MSDP-MIB", "msdpPeerState"), ("MSDP-MIB", "msdpPeerInSAs"), ("MSDP-MIB", "msdpPeerOutSAs"), ("MSDP-MIB", "msdpPeerInSARequests"), ("MSDP-MIB", "msdpPeerOutSARequests"), ("MSDP-MIB", "msdpPeerInControlMessages"), ("MSDP-MIB", "msdpPeerOutControlMessages"), ("MSDP-MIB", "msdpPeerFsmEstablishedTransitions"), ("MSDP-MIB", "msdpPeerFsmEstablishedTime"), ("MSDP-MIB", "msdpPeerLocalAddress"), ("MSDP-MIB", "msdpPeerRemotePort"), ("MSDP-MIB", "msdpPeerLocalPort"), ("MSDP-MIB", "msdpPeerConnectRetryInterval"), ("MSDP-MIB", "msdpPeerHoldTimeConfigured"), ("MSDP-MIB", "msdpPeerKeepAliveConfigured"), ("MSDP-MIB", "msdpPeerInMessageTime"), ("MSDP-MIB", "msdpPeerConnectionAttempts"), ("MSDP-MIB", "msdpPeerStatus"), ("MSDP-MIB", "msdpPeerDiscontinuityTime"),))
if mibBuilder.loadTexts: msdpMIBPeerGroup2.setDescription('A collection of objects for managing MSDP peers.')
mibBuilder.exportSymbols("MSDP-MIB", msdpSACacheOriginRP=msdpSACacheOriginRP, PYSNMP_MODULE_ID=msdpMIB, msdpRPAddress=msdpRPAddress, msdpPeerRemotePort=msdpPeerRemotePort, msdpPeerHoldTimeConfigured=msdpPeerHoldTimeConfigured, msdpPeerInNotifications=msdpPeerInNotifications, msdpSACacheInDataPackets=msdpSACacheInDataPackets, msdpPeerConnectionAttempts=msdpPeerConnectionAttempts, msdpPeerInControlMessages=msdpPeerInControlMessages, msdpPeerKeepAliveConfigured=msdpPeerKeepAliveConfigured, msdpSACacheStatus=msdpSACacheStatus, msdpPeerInSAResponses=msdpPeerInSAResponses, msdpBackwardTransition=msdpBackwardTransition, msdpMIBPeerGroup2=msdpMIBPeerGroup2, msdpMIBCompliance=msdpMIBCompliance, msdpPeerDiscontinuityTime=msdpPeerDiscontinuityTime, msdpMIBConformance=msdpMIBConformance, msdpSACacheRPFPeer=msdpSACacheRPFPeer, msdpMIBRequestsGroup=msdpMIBRequestsGroup, msdpRequestsTable=msdpRequestsTable, msdpPeerDataTtl=msdpPeerDataTtl, msdpMIBEncapsulationGroup=msdpMIBEncapsulationGroup, msdpRequestsPeer=msdpRequestsPeer, msdpPeerOutSARequests=msdpPeerOutSARequests, msdpMIBRPGroup=msdpMIBRPGroup, msdpNumSACacheEntries=msdpNumSACacheEntries, msdpPeerOutSAs=msdpPeerOutSAs, msdpMeshGroupEntry=msdpMeshGroupEntry, msdpMIBPeerGroup=msdpMIBPeerGroup, msdpMIBCompliances=msdpMIBCompliances, msdpMIBMeshGroupGroup=msdpMIBMeshGroupGroup, msdpRequestsStatus=msdpRequestsStatus, msdpSACacheInSAs=msdpSACacheInSAs, msdpSACacheSourceAddr=msdpSACacheSourceAddr, msdpMIBobjects=msdpMIBobjects, msdpPeerStatus=msdpPeerStatus, msdpRequestsEntry=msdpRequestsEntry, msdpSACacheExpiryTime=msdpSACacheExpiryTime, msdpSACacheGroupAddr=msdpSACacheGroupAddr, msdpMeshGroupStatus=msdpMeshGroupStatus, msdpMIBNotificationGroup=msdpMIBNotificationGroup, msdpEnabled=msdpEnabled, msdpSACacheEntry=msdpSACacheEntry, msdpMIBReadOnlyCompliance=msdpMIBReadOnlyCompliance, msdpMIBSACacheGroup=msdpMIBSACacheGroup, msdpPeerInMessageTime=msdpPeerInMessageTime, msdpEstablished=msdpEstablished, msdpPeerState=msdpPeerState, msdpPeerLocalPort=msdpPeerLocalPort, msdpPeerRemoteAddress=msdpPeerRemoteAddress, msdpPeerFsmEstablishedTime=msdpPeerFsmEstablishedTime, msdpPeerOutNotifications=msdpPeerOutNotifications, msdpMIBFullCompliance=msdpMIBFullCompliance, msdpPeerLocalAddress=msdpPeerLocalAddress, msdpRequestsGroupAddress=msdpRequestsGroupAddress, msdpMIBGroups=msdpMIBGroups, msdp=msdp, msdpMeshGroupName=msdpMeshGroupName, msdpPeerFsmEstablishedTransitions=msdpPeerFsmEstablishedTransitions, msdpCacheLifetime=msdpCacheLifetime, msdpPeerInSARequests=msdpPeerInSARequests, msdpPeerOutSAResponses=msdpPeerOutSAResponses, msdpPeerOutControlMessages=msdpPeerOutControlMessages, msdpPeerLastError=msdpPeerLastError, msdpSACacheTable=msdpSACacheTable, msdpTraps=msdpTraps, msdpPeerInDataPackets=msdpPeerInDataPackets, msdpSACacheUpTime=msdpSACacheUpTime, msdpPeerEntry=msdpPeerEntry, msdpPeerOutDataPackets=msdpPeerOutDataPackets, msdpMIB=msdpMIB, msdpPeerTable=msdpPeerTable, msdpPeerProcessRequestsFrom=msdpPeerProcessRequestsFrom, msdpSACachePeerLearnedFrom=msdpSACachePeerLearnedFrom, msdpPeerConnectRetryInterval=msdpPeerConnectRetryInterval, msdpMIBGlobalsGroup=msdpMIBGlobalsGroup, msdpRequestsGroupMask=msdpRequestsGroupMask, msdpMeshGroupPeerAddress=msdpMeshGroupPeerAddress, msdpPeerEncapsulationType=msdpPeerEncapsulationType, msdpPeerRPFFailures=msdpPeerRPFFailures, msdpMeshGroupTable=msdpMeshGroupTable, msdpPeerInSAs=msdpPeerInSAs)



#
# PySNMP MIB module CIRCUIT-IF-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/CIRCUIT-IF-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:06:52 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ConstraintsIntersection, ValueRangeConstraint, ValueSizeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ConstraintsIntersection", "ValueRangeConstraint", "ValueSizeConstraint", "SingleValueConstraint")
( InterfaceIndex, ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "ifIndex")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, iso, NotificationType, MibIdentifier, Counter64, Bits, ModuleIdentity, Counter32, mib_2, ObjectIdentity, IpAddress, Unsigned32, Gauge32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32", "iso", "NotificationType", "MibIdentifier", "Counter64", "Bits", "ModuleIdentity", "Counter32", "mib-2", "ObjectIdentity", "IpAddress", "Unsigned32", "Gauge32")
( RowPointer, TextualConvention, DisplayString, StorageType, RowStatus, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowPointer", "TextualConvention", "DisplayString", "StorageType", "RowStatus", "TimeStamp")
circuitIfMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 94)).setRevisions(("2002-01-03 00:00",))
if mibBuilder.loadTexts: circuitIfMIB.setLastUpdated('200201030000Z')
if mibBuilder.loadTexts: circuitIfMIB.setOrganization('IETF Frame Relay Service MIB Working Group')
if mibBuilder.loadTexts: circuitIfMIB.setContactInfo('IETF Frame Relay Service MIB (frnetmib) Working Group\n\n           WG Charter:    http://www.ietf.org/html.charters/\n                                 frnetmib-charter.html\n           WG-email:      frnetmib@sunroof.eng.sun.com\n           Subscribe:     frnetmib-request@sunroof.eng.sun.com\n           Email Archive: ftp://ftp.ietf.org/ietf-mail-archive/frnetmib\n\n           Chair:      Andy Malis\n                       Vivace Networks\n           Email:      Andy.Malis@vivacenetworks.com\n\n           WG editor:  Robert Steinberger\n                       Paradyne Networks and\n                       Fujitsu Network Communications\n           Email:      robert.steinberger@fnc.fujitsu.com\n\n           Co-author:  Orly Nicklass\n                       RAD Data Communications Ltd.\n           EMail:      Orly_n@rad.co.il')
if mibBuilder.loadTexts: circuitIfMIB.setDescription('The MIB module to allow insertion of selected circuit into\n             the ifTable.')
class CiFlowDirection(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("transmit", 1), ("receive", 2), ("both", 3),)

ciObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 94, 1))
ciCapabilities = MibIdentifier((1, 3, 6, 1, 2, 1, 94, 2))
ciConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 94, 3))
ciCircuitTable = MibTable((1, 3, 6, 1, 2, 1, 94, 1, 1), )
if mibBuilder.loadTexts: ciCircuitTable.setDescription('The Circuit Interface Circuit Table.')
ciCircuitEntry = MibTableRow((1, 3, 6, 1, 2, 1, 94, 1, 1, 1), ).setIndexNames((0, "CIRCUIT-IF-MIB", "ciCircuitObject"), (0, "CIRCUIT-IF-MIB", "ciCircuitFlow"))
if mibBuilder.loadTexts: ciCircuitEntry.setDescription('An entry in the Circuit Interface Circuit Table.')
ciCircuitObject = MibTableColumn((1, 3, 6, 1, 2, 1, 94, 1, 1, 1, 1), RowPointer())
if mibBuilder.loadTexts: ciCircuitObject.setDescription('This value contains the RowPointer that uniquely\n\n             describes the circuit that is to be added to this table.\n             Any RowPointer that will force the size of OBJECT\n             IDENTIFIER of the row to grow beyond the legal limit\n             MUST be rejected.\n\n             The purpose of this object is to point a network manager\n             to the table in which the circuit was created as well as\n             define the circuit on which the interface is defined.\n\n             Valid tables for this object include the frCircuitTable\n             from the Frame Relay DTE MIB(FRAME-RELAY-DTE-MIB), the\n             frPVCEndptTable from the Frame Relay Service MIB\n             (FRNETSERV-MIB), and the aal5VccTable from the ATM MIB\n             (ATM MIB).  However, including circuits from other MIB\n             tables IS NOT prohibited.')
ciCircuitFlow = MibTableColumn((1, 3, 6, 1, 2, 1, 94, 1, 1, 1, 2), CiFlowDirection())
if mibBuilder.loadTexts: ciCircuitFlow.setDescription('The direction of data flow through the circuit for which\n             the virtual interface is defined.  The following define\n             the information that the virtual interface will report.\n\n                transmit(1) - Only transmitted frames\n                receive(2)  - Only received frames\n                both(3)     - Both transmitted and received frames.\n\n             It is recommended that the ifDescr of the circuit\n             interfaces that are not both(3) SHOULD have text warning\n             the operators that the particular interface represents\n             only half the traffic on the circuit.')
ciCircuitStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 94, 1, 1, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ciCircuitStatus.setDescription('The status of the current row.  This object is\n             used to add, delete, and disable rows in this\n             table.  When the status changes to active(1), a row\n             will also be added to the interface map table below\n             and a row will be added to the ifTable.  These rows\n             SHOULD not be removed until the status is changed\n             from active(1).  The value of ifIndex for the row that\n\n             is added to the ifTable is determined by the agent\n             and MUST follow the rules of the ifTable.  The value\n             of ifType for that interface will be frDlciEndPt(193)\n             for a frame relay circuit, atmVciEndPt(194) for an\n             ATM circuit, or another ifType defining the circuit\n             type for any other circuit.\n\n             When this object is set to destroy(6), the associated\n             row in the interface map table will be removed and the\n             ifIndex will be removed from the ifTable.  Removing\n             the ifIndex MAY initiate a chain of events that causes\n             changes to other tables as well.\n\n             The rows added to this table MUST have a valid object\n             identifier for ciCircuitObject.  This means that the\n             referenced object must exist and it must be in a table\n             that supports circuits.\n\n             The object referenced by ciCircuitObject MUST exist\n             prior to transitioning a row to active(1).  If at any\n             point the object referenced by ciCircuitObject does not\n             exist or the row containing it is not in the active(1)\n             state, the status SHOULD either age out the row or\n             report notReady(3).  The effects transitioning from\n             active(1) to notReady(3) are the same as those caused\n             by setting the status to destroy(6).\n\n             Each row in this table relies on information from other\n             MIB modules.  The rules persistence of data SHOULD follow\n             the same rules as those of the underlying MIB module.\n             For example, if the circuit defined by ciCircuitObject\n             would normally be stored in non-volatile memory, then\n             the row SHOULD also be non-volatile.')
ciCircuitIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 94, 1, 1, 1, 4), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ciCircuitIfIndex.setDescription('The ifIndex that the agent assigns to this row.')
ciCircuitCreateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 94, 1, 1, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ciCircuitCreateTime.setDescription('This object returns the value of sysUpTime at the time\n             the value of ciCircuitStatus last transitioned to\n             active(1).  If ciCircuitStatus has never been active(1),\n             this object SHOULD return 0.')
ciCircuitStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 94, 1, 1, 1, 6), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ciCircuitStorageType.setDescription('The storage type used for this row.')
ciIfMapTable = MibTable((1, 3, 6, 1, 2, 1, 94, 1, 2), )
if mibBuilder.loadTexts: ciIfMapTable.setDescription('The Circuit Interface Map Table.')
ciIfMapEntry = MibTableRow((1, 3, 6, 1, 2, 1, 94, 1, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: ciIfMapEntry.setDescription('An entry in the Circuit Interface Map Table.')
ciIfMapObject = MibTableColumn((1, 3, 6, 1, 2, 1, 94, 1, 2, 1, 1), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ciIfMapObject.setDescription('This value contains the value of RowPointer that\n             corresponds to the current ifIndex.')
ciIfMapFlow = MibTableColumn((1, 3, 6, 1, 2, 1, 94, 1, 2, 1, 2), CiFlowDirection()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ciIfMapFlow.setDescription('The value contains the value of ciCircuitFlow that\n             corresponds to the current ifIndex.')
ciIfLastChange = MibScalar((1, 3, 6, 1, 2, 1, 94, 1, 3), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ciIfLastChange.setDescription('The value of sysUpTime at the most recent change to\n             ciCircuitStatus for any row in ciCircuitTable.')
ciIfNumActive = MibScalar((1, 3, 6, 1, 2, 1, 94, 1, 4), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ciIfNumActive.setDescription('The number of active rows in ciCircuitTable.')
ciMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 94, 3, 1))
ciMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 94, 3, 2))
ciCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 94, 3, 2, 1)).setObjects(*(("CIRCUIT-IF-MIB", "ciCircuitGroup"), ("CIRCUIT-IF-MIB", "ciIfMapGroup"), ("CIRCUIT-IF-MIB", "ciStatsGroup"),))
if mibBuilder.loadTexts: ciCompliance.setDescription('The compliance statement for SNMP entities\n\n             which support of the Circuit Interfaces MIB module.\n             This group defines the minimum level of support\n             required for compliance.')
ciCircuitGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 94, 3, 1, 1)).setObjects(*(("CIRCUIT-IF-MIB", "ciCircuitStatus"), ("CIRCUIT-IF-MIB", "ciCircuitIfIndex"), ("CIRCUIT-IF-MIB", "ciCircuitCreateTime"), ("CIRCUIT-IF-MIB", "ciCircuitStorageType"),))
if mibBuilder.loadTexts: ciCircuitGroup.setDescription('A collection of required objects providing\n            information from the circuit table.')
ciIfMapGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 94, 3, 1, 2)).setObjects(*(("CIRCUIT-IF-MIB", "ciIfMapObject"), ("CIRCUIT-IF-MIB", "ciIfMapFlow"),))
if mibBuilder.loadTexts: ciIfMapGroup.setDescription('A collection of required objects providing\n            information from the interface map table.')
ciStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 94, 3, 1, 3)).setObjects(*(("CIRCUIT-IF-MIB", "ciIfLastChange"), ("CIRCUIT-IF-MIB", "ciIfNumActive"),))
if mibBuilder.loadTexts: ciStatsGroup.setDescription('A collection of statistical metrics used to help manage\n            the ciCircuitTable.')
mibBuilder.exportSymbols("CIRCUIT-IF-MIB", ciCircuitStorageType=ciCircuitStorageType, ciIfLastChange=ciIfLastChange, ciCircuitTable=ciCircuitTable, ciIfNumActive=ciIfNumActive, ciCircuitIfIndex=ciCircuitIfIndex, ciCircuitEntry=ciCircuitEntry, ciCapabilities=ciCapabilities, circuitIfMIB=circuitIfMIB, ciMIBCompliances=ciMIBCompliances, ciIfMapGroup=ciIfMapGroup, ciCircuitCreateTime=ciCircuitCreateTime, ciIfMapEntry=ciIfMapEntry, ciStatsGroup=ciStatsGroup, ciIfMapTable=ciIfMapTable, ciCircuitObject=ciCircuitObject, ciCircuitFlow=ciCircuitFlow, CiFlowDirection=CiFlowDirection, ciConformance=ciConformance, ciIfMapObject=ciIfMapObject, ciCircuitGroup=ciCircuitGroup, ciIfMapFlow=ciIfMapFlow, ciCompliance=ciCompliance, ciMIBGroups=ciMIBGroups, ciObjects=ciObjects, ciCircuitStatus=ciCircuitStatus, PYSNMP_MODULE_ID=circuitIfMIB)
